@@ -12,7 +12,7 @@ extern "C" {
 #define R_CRITICAL_ENABLED 0
 #define DEBUGGER 1
 #define HAVE_DECL_ADDR_NO_RANDOMIZE 1
-#define HAVE_ARC4RANDOM_UNIFORM 0
+#define HAVE_ARC4RANDOM_UNIFORM 1
 #define HAVE_EXPLICIT_BZERO 1
 #define HAVE_EXPLICIT_MEMSET 0
 #define HAVE_CLOCK_NANOSLEEP 1
@@ -20,6 +20,7 @@ extern "C" {
 #define WANT_THREADS 0
 #define WANT_CAPSTONE 1
 #define HAVE_LINUX_CAN_H 0
+#define R2_USE_NEW_ABI 0
 
 #define R_BUILDSYSTEM "meson"
 #if 0 == 1
@@ -43,20 +44,20 @@ extern "C" {
 #define R2_PREFIX "/usr"
 #define R2_ETCDIR "/usr/etc"
 #define R2_LIBDIR "/usr/lib"
-#define R2_BINDIR ""
+#define R2_BINDIR "/usr/bin"
 #define R2_INCDIR "/usr/include/libr"
 #define R2_DATDIR "/usr/share"
-#define R2_WWWROOT "/usr/share/radare2/5.9.0/www"
-#define R2_PLUGINS "lib/radare2/5.9.0"
-#define R2_EXTRAS "lib/radare2-extras/5.9.0"
-#define R2_BINDINGS "lib/radare2-bindings/5.9.0"
+#define R2_WWWROOT "/usr/share/radare2/5.9.2/www"
+#define R2_PLUGINS "lib/radare2/5.9.2"
+#define R2_EXTRAS "lib/radare2-extras/5.9.2"
+#define R2_BINDINGS "lib/radare2-bindings/5.9.2"
 #define R2_DATDIR_R2 "share/radare2"
-#define R2_SDB "share/radare2/5.9.0"
-#define R2_ZIGNS "share/radare2/5.9.0/zigns"
-#define R2_THEMES "share/radare2/5.9.0/cons"
+#define R2_SDB "share/radare2/5.9.2"
+#define R2_ZIGNS "share/radare2/5.9.2/zigns"
+#define R2_THEMES "share/radare2/5.9.2/cons"
 #define R2_FORTUNES R_JOIN_3_PATHS ("/usr/share", "doc", "radare2")
-#define R2_FLAGS "share/radare2/5.9.0/flag"
-#define R2_HUD "share/radare2/5.9.0/hud"
+#define R2_FLAGS "share/radare2/5.9.2/flag"
+#define R2_HUD "share/radare2/5.9.2/hud"
 #else
 #if R2__WINDOWS__ || _MSC_VER
 #define R2_PREFIX "."
@@ -73,7 +74,7 @@ extern "C" {
 #define R2_PREFIX "/usr"
 #define R2_ETCDIR "/usr/etc"
 #define R2_LIBDIR "/usr/lib"
-#define R2_BINDIR ""
+#define R2_BINDIR "/usr/bin"
 #define R2_INCDIR "/usr/include/libr/libr"
 #define R2_DATDIR "/usr/share"
 #define R2_WWWROOT R2_DATDIR "/radare2/" R2_VERSION "/www"
