@@ -1,11 +1,12 @@
 #ifndef R_STR_H
 #define R_STR_H
 
-#include <wchar.h>
-#include <stdarg.h>
 #include "r_str_util.h"
 #include <r_list.h>
+#include <r_vec.h>
 #include <r_types_base.h>
+#include <stdarg.h>
+#include <wchar.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -29,12 +30,22 @@ typedef struct {
 	bool weak;
 } RString;
 
+// string split using rvec
+typedef struct {
+	ut16 from;
+	ut16 to;
+} RStringSlice;
+
+R_VEC_TYPE (RVecStringSlice, RStringSlice);
+
+
 typedef int (*RStrRangeCallback) (void *, int);
 
 // can be replaced with RString
 #define r_strf_buffer(s) char strbuf[s]
-#define r_strf_var(n,s, f, ...) char n[s]; snprintf (n, s, f, __VA_ARGS__);
-#define r_strf(s,...) (snprintf (strbuf, sizeof (strbuf), s, __VA_ARGS__)?strbuf: strbuf)
+#define r_strf_var(n,s,f, ...) char n[s]; snprintf (n, s, f, __VA_ARGS__);
+#define r_strf(s,...) (snprintf (strbuf, sizeof (strbuf), s, __VA_ARGS__)? strbuf: strbuf)
+#define r_str_var(n,s,f) char n[s]; r_str_ncpy (n, f, s);
 
 typedef struct r_charset_rune_t {
 	ut8 *ch;
@@ -77,6 +88,7 @@ R_API const char *r_str_pad(const char ch, int len);
 R_API const char *r_str_rstr(const char *base, const char *p);
 R_API const char *r_strstr_ansi(const char *a, const char *b);
 R_API const char *r_str_rchr(const char *base, const char *p, int ch);
+R_API const char *r_str_nchr(const char *str, char chr, int maxlen);
 R_API const char *r_str_closer_chr(const char *b, const char *s);
 R_API int r_str_bounds(const char *str, int *h);
 R_API bool r_str_eq(const char *s1, const char *s2);
@@ -95,7 +107,6 @@ R_API void r_str_filter_zeroline(char *str, int len);
 R_API size_t r_str_utf8_codepoint(const char *s, size_t left);
 R_API bool r_str_char_fullwidth(const char *s, size_t left);
 R_API int r_str_write(int fd, const char *b);
-R_API size_t r_str_ncpy(char *dst, const char *src, size_t n);
 R_API void r_str_sanitize(char *c);
 R_API char *r_str_sanitize_sdb_key(const char *s);
 R_API const char *r_str_casestr(const char *a, const char *b);
@@ -103,6 +114,13 @@ R_API const char *r_str_firstbut(const char *s, char ch, const char *but);
 R_API const char *r_str_firstbut_escape(const char *s, char ch, const char *but);
 R_API const char *r_str_lastbut(const char *s, char ch, const char *but);
 R_API int r_str_split(char *str, char ch);
+R_API char *r_str_slice(const char *str, RStringSlice s);
+R_API const char *r_str_asciitable(void);
+#if R2_USE_NEW_ABI
+R_API const char *r_str_chartable(int c);
+#endif
+
+R_API RVecStringSlice *r_str_split_vec(const char *str, const char *c, int n);
 R_API RList *r_str_split_list(char *str, const char *c, int n);
 R_API RList *r_str_split_duplist(const char *str, const char *c, bool trim);
 R_API size_t *r_str_split_lines(char *str, size_t *count);
@@ -158,7 +176,7 @@ R_API char *r_str_ansi_crop(const char *str, unsigned int x, unsigned int y, uns
 R_API int r_str_word_count(const char *string);
 R_API size_t r_str_char_count(const char *string, char ch);
 R_API char *r_str_word_get0set(char *stra, int stralen, int idx, const char *newstr, int *newlen);
-R_API char *r_str_insert(char *src, int pos, const char *str);
+// R_UNUSED R_API char *r_str_insert(char *src, int pos, const char *str);
 R_API int r_str_word_set0(char *str);
 R_API int r_str_word_set0_stack(char *str);
 R_API const char *r_str_word_get0(const char *str, int idx);
@@ -168,6 +186,7 @@ R_API void r_str_trim_emptylines(char *str);
 R_API int r_str_ntrim(char *str, int n);
 R_API char *r_str_wrap(const char *str, int w);
 R_API char *r_str_trim_dup(const char *str);
+R_API char *r_str_trim_ndup(const char *str, size_t n);
 R_API char *r_str_trim_lines(char *str);
 R_API void r_str_trim_head(char *str);
 R_API const char *r_str_trim_head_ro(const char *str);
@@ -184,10 +203,8 @@ R_API const char *r_sub_str_rchr(const char *str, int start, int end, char chr);
 R_API char *r_str_ichr(char *str, char chr);
 R_API bool r_str_ccmp(const char *dst, const char *orig, int ch);
 R_API bool r_str_cmp_list(const char *list, const char *item, char sep);
-R_API R_DEPRECATE int r_str_cmp(const char *dst, const char *orig, int len); // R2_590 R_DEPRECATE
 R_API int r_str_casecmp(const char *dst, const char *orig);
 R_API int r_str_ncasecmp(const char *dst, const char *orig, size_t n);
-R_API int r_str_ccpy(char *dst, char *orig, int ch);
 R_API const char *r_str_get(const char *str);
 R_API const char *r_str_get_fail(const char *str, const char *failstr);
 R_API const char *r_str_getf(const char *str);
@@ -196,31 +213,9 @@ R_API int r_str_inject(char *begin, char *end, char *str, int maxlen);
 R_API int r_str_delta(char *p, char a, char b);
 R_API void r_str_filter(char *str, int len);
 R_API const char *r_str_tok(const char *str1, const char b, size_t len);
-/* temporal solution until 5.9.0 is out */
-static inline char *r_str_tok_r(char *str, const char *delim, char **save_ptr) {
-	char *ret = NULL;
+R_API char *r_str_tok_next(char *s);
 
-	if (str == NULL) {
-		str = *save_ptr;
-	}
-
-	str += strspn (str, delim);
-
-	if (*str == '\0') {
-		return NULL;
-	}
-
-	ret = str;
-
-	str += strcspn (str, delim);
-
-	if (*str) {
-		*str++ = '\0';
-	}
-
-	*save_ptr = str;
-	return ret;
-}
+R_API char *r_str_tok_r(char *str, const char *delim, char **save_ptr);
 R_API wchar_t *r_str_mb_to_wc(const char *buf);
 R_API char *r_str_wc_to_mb(const wchar_t *buf);
 R_API wchar_t *r_str_mb_to_wc_l(const char *buf, int len);
@@ -275,17 +270,28 @@ R_API void r_str_trim_path(char *s);
 R_API ut8 r_str_contains_macro(const char *input_value);
 R_API void r_str_truncate_cmd(char *string);
 R_API bool r_str_glob(const char *str, const char *glob);
-R_API int r_str_binstr2bin(const char *str, ut8 *out, int outlen);
 R_API char *r_str_between(const char *str, const char *prefix, const char *suffix);
 #undef r_str_startswith
+static inline size_t r_str_ncpy(char *dst, const char *src, size_t n) {
+	size_t i;
+
+	// do not do anything if n is 0
+	if (n == 0) {
+		return 0;
+	}
+
+	n--;
+	for (i = 0; src[i] && n > 0; i++, n--) {
+		dst[i] = src[i];
+	}
+	dst[i] = 0;
+	return i;
+}
 R_API bool r_str_startswith(const char *str, const char *needle);
-R_UNUSED static bool r_str_startswith_inline(const char *str, const char *needle) {
+R_UNUSED static inline bool r_str_startswith_inline(const char *str, const char *needle) {
 	if (!str || !needle) {
 		return false;
 	}
-	if (str == needle) {
-		return true;
-	}
 	return !strncmp (str, needle, strlen (needle));
 }
 #define r_str_startswith r_str_startswith_inline
@@ -311,6 +317,12 @@ R_API char *r_str_donut(int size);
 R_API char *r_str_version(const char *program);
 R_API char *r_str_ss(const char* msg, const char *nl, int cs);
 
+R_API char *r_str_after(char *s, char c);
+R_API int r_str_printf(R_NONNULL char *buffer, size_t buffer_size, R_NONNULL const char *format, ...);
+  /// __attribute__ ((format (printf, 3, 4)));
+R_API int r_str_scanf(R_NONNULL const char *buffer, R_NONNULL const char *format, ...);
+  /// __attribute__ ((format (scanf, 2, 3)));
+
 // rstr
 
 R_API char *r_string_get(const RString *s, int *len);
